# Table of Contents

- [it-component-naming-rule-extension](<./it-component-naming-rule-extension.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [IT Component Naming Rule Extension](<./IT-Component-Naming-Rule-Extension.md>)
  - [Overview](<./IT-Component-Naming-Rule-Extension/Overview.md>)
  - [How It Works](<./IT-Component-Naming-Rule-Extension/How-It-Works.md>)
  - [Prerequisite](<./IT-Component-Naming-Rule-Extension/Prerequisite.md>)
  - [How to Activate](<./IT-Component-Naming-Rule-Extension/How-to-Activate.md>)
  - [Frequently Asked Questions](<./IT-Component-Naming-Rule-Extension/Frequently-Asked-Questions.md>)
  - [Was this page helpful?](<./IT-Component-Naming-Rule-Extension/Was-this-page-helpful.md>)
